@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "attributes/showfoldernotesattribute.h"
 #include "notesharedglobalconfig.h"
 #include <Akonadi/ManageAccountWidget>
-#include <Akonadi/Notes/NoteUtils>
+#include <Akonadi/NoteUtils>
 
 #include <Akonadi/CollectionFilterProxyModel>
 #include <Akonadi/CollectionModifyJob>
@@ -189,9 +189,7 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     slotUpdateButtons();
 }
 
-KNoteCollectionConfigWidget::~KNoteCollectionConfigWidget()
-{
-}
+KNoteCollectionConfigWidget::~KNoteCollectionConfigWidget() = default;
 
 void KNoteCollectionConfigWidget::slotUpdateButtons()
 {
